--[[---------------------------------------------------------------------------
	
	Creator: x[N]ir - #4841
	This work is licensed under the Creative Commons 
	Attribution-NonCommercial-ShareAlike 4.0 International License. 
	License details: http://creativecommons.org/licenses/by-nc-sa/4.0/
	
-----------------------------------------------------------------------------]]

--[[---------------------------------------------
	MENU_init
-----------------------------------------------]]
function ATM.MENU_init( id )
	local account = ATM.Accounts[ id ]

	--> Images ID
	local bgImageID = image( 'gfx/xNir/atm/menu/background.png', 350, 230,
		2, id )
	local boxImageID = image( 'gfx/xNir/atm/menu/box.png', 350, 230,
		2, id )
	local barImageID = image( 'gfx/xNir/atm/menu/bar.png', 240, 250,
		2, id )
	
	--> Cache
	imagealpha( bgImageID, 0 )
	imagealpha( barImageID, 0 )

	--> Effects
	tween_alpha( bgImageID, 1000, 1 )
	imagecolor( barImageID, 0, 0, 0 )

	--> Image Alpha
	timer( 1000, "parse", 'lua imagealpha(' .. barImageID .. ',1)' )

	--> Loading Bar
	timer( 1000, "parse", 'lua ATM.MENU_updateLoading(' .. id .. ')' )

	--> Update
	account.images[ "bg" ] = bgImageID
	account.images[ "box" ] = boxImageID
	account.images[ "bar" ] = barImageID
end

--[[---------------------------------------------
	MENU_updateLoading
-----------------------------------------------]]
function ATM.MENU_updateLoading( id )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )
	local time = math.random( 500, 1000 )
	local progressAmount = math.random( 5, 15 )

	if not atm then
		return
	end

	--> Update
	atm.loadingPercent = atm.loadingPercent + progressAmount
	atm.status = ATM.LOADING

	--> Percent
	if atm.loadingPercent > 100 then
		atm.loadingPercent = 100
	end

	local newBarX = 340 - ( 100 - atm.loadingPercent )

	--> Loading
	account.texts[ "loading" ] =
		ATM.TEXT_display( id, 0, 'Loading: ' .. atm.loadingPercent .. "%", 300, 200,
			"000000000" )

	--> Effect
	if account.images[ "bar" ] then
		tween_move( account.images[ "bar" ], time, newBarX, 250 )
		tween_scale( account.images[ "bar" ], time, atm.loadingPercent, 1 )
	end

	--> Percent
	if atm.loadingPercent == 100 then
		timer( time, 'parse', 'lua ATM.MENU_main(' .. id .. ')' )
		return
	end	

	--> Timer
	timer( time, 'parse', 'lua ATM.MENU_updateLoading(' .. id .. ')' )
end

--[[---------------------------------------------
	MENU_main
-----------------------------------------------]]
function ATM.MENU_main( id )
	--> AFK / Gone away Timer
	freetimer( "parse", "lua ATM.die(" .. id .. ")" )
	timer( ATM.AFK_DELAY * 1000, "parse", "lua ATM.die(" .. id .. ")" )

	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )
	atm.status = ATM.LOADED
	atm.page = ATM.MAIN

	--> Texts
	account.texts[ "welcome" ] =
		ATM.TEXT_display( id, 0, 'Welcome Back ! <' .. player( id, "name" ) .. '>', 
			250, 150, "000000000" )
	account.texts[ "balance" ] =
		ATM.TEXT_display( id, 1, 'Your balance: ' .. account.money .. "$", 
			250, 180, "000000000" )
	account.texts[ "deposit" ] =
		ATM.TEXT_display( id, 2, 'Deposit', 260, 242, "000000000" )
	account.texts[ "withdraw" ] =
		ATM.TEXT_display( id, 3, 'Withdraw', 380, 242, "000000000" )
	account.texts[ "info" ] =
		ATM.TEXT_display( id, 4, 'Info', 260, 302, "000000000" )
	account.texts[ "exit" ] =
		ATM.TEXT_display( id, 5, 'Exit', 400, 302, "000000000" )

	--> Images
	local depositImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 250,
		2, id )
	local withdrawImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 250,
		2, id )
	local infoImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 310,
		2, id )
	local exitImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 310,
		2, id )

	--> Update
	account.images[ "deposit" ] = depositImageID
	account.images[ "withdraw" ] = withdrawImageID
	account.images[ "info" ] = infoImageID
	account.images[ "exit" ] = exitImageID
end

--[[---------------------------------------------
	MENU_exit
-----------------------------------------------]]
function ATM.MENU_exit( id )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )

	account.texts[ "bye" ] =
		ATM.TEXT_display( id, 0, 'See you soon ! <' .. player( id, "name" ) .. '>', 
			250, 150, "000000000" )
end

--[[---------------------------------------------
	MENU_deposit
-----------------------------------------------]]
function ATM.MENU_deposit( id )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )
	atm.page = ATM.DEPOSIT

	--> Texts
	account.texts[ "deposit" ] =
		ATM.TEXT_display( id, 0, '> Deposit <', 300, 120, "000000000" )
	account.texts[ "balance" ] =
		ATM.TEXT_display( id, 1, 'Your balance: ' .. account.money .. "$", 
			285, 140, "000000000" )
		account.texts[ "b100" ] =
		ATM.TEXT_display( id, 2, '100$', 260, 182, "000000000" )
	account.texts[ "b500" ] =
		ATM.TEXT_display( id, 3, '500$', 400, 182, "000000000" )
	account.texts[ "b1000" ] =
		ATM.TEXT_display( id, 4, '1000$', 260, 242, "000000000" )
	account.texts[ "b2000" ] =
		ATM.TEXT_display( id, 5, '2000$', 400, 242, "000000000" )
	account.texts[ "return" ] =
		ATM.TEXT_display( id, 6, 'Return', 260, 302, "000000000" )

	local b100ImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 190,
		2, id )
	local b500ImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 190,
		2, id )
	local b1000ImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 250,
		2, id )
	local b2000ImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 250,
		2, id )
	local returnImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 310,
		2, id )

	--> Update
	account.images[ "b100" ] = b100ImageID
	account.images[ "b500" ] = b500ImageID
	account.images[ "b1000" ] = b1000ImageID
	account.images[ "b2000" ] = b2000ImageID
	account.images[ "return" ] = returnImageID
end

--[[---------------------------------------------
	MENU_withdraw
-----------------------------------------------]]
function ATM.MENU_withdraw( id )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )
	atm.page = ATM.WITHDRAW

	--> Texts
	account.texts[ "withdraw" ] =
		ATM.TEXT_display( id, 0, '> Withdraw <', 300, 120, "000000000" )
	account.texts[ "balance" ] =
		ATM.TEXT_display( id, 1, 'Your balance: ' .. account.money .. "$", 
			285, 140, "000000000" )
		account.texts[ "b100" ] =
		ATM.TEXT_display( id, 2, '100$', 260, 182, "000000000" )
	account.texts[ "b500" ] =
		ATM.TEXT_display( id, 3, '500$', 400, 182, "000000000" )
	account.texts[ "b1000" ] =
		ATM.TEXT_display( id, 4, '1000$', 260, 242, "000000000" )
	account.texts[ "b2000" ] =
		ATM.TEXT_display( id, 5, '2000$', 400, 242, "000000000" )
	account.texts[ "return" ] =
		ATM.TEXT_display( id, 6, 'Return', 260, 302, "000000000" )

	local b100ImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 190,
		2, id )
	local b500ImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 190,
		2, id )
	local b1000ImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 250,
		2, id )
	local b2000ImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 250,
		2, id )
	local returnImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 310,
		2, id )

	--> Update
	account.images[ "b100" ] = b100ImageID
	account.images[ "b500" ] = b500ImageID
	account.images[ "b1000" ] = b1000ImageID
	account.images[ "b2000" ] = b2000ImageID
	account.images[ "return" ] = returnImageID
end

--[[---------------------------------------------
	MENU_error
-----------------------------------------------]]
function ATM.MENU_error( id, errorMsg )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )
	atm.page = ATM.ERROR

	--> Texts
	account.texts[ "error" ] =
		ATM.TEXT_display( id, 1, 'Error: ' .. errorMsg, 
			270, 200, "255000000" )

	timer( 5000, "parse", "lua ATM.MENU_main(" .. id .. ")" )
end

--[[---------------------------------------------
	MENU_info
-----------------------------------------------]]
function ATM.MENU_info( id )
	--> Vars
	local account = ATM.Accounts[ id ]
	local atm = ATM.CORE_getCurrentATM( id )

	--> Update
	ATM.MENU_remove( id )
	atm.page = ATM.INFO

	--> Texts
	account.texts[ "mod" ] =
		ATM.TEXT_display( id, 0, 'Project: ' .. ATM._PROJECT, 
			285, 150, "000000000" )
	account.texts[ "author" ] =
		ATM.TEXT_display( id, 1, 'Author: ' .. ATM._AUTHOR, 
			285, 170, "000000000" )
	account.texts[ "version" ] =
		ATM.TEXT_display( id, 2, 'Version: ' .. ATM._VERSION, 
			285, 190, "000000000" )
	account.texts[ "return" ] =
		ATM.TEXT_display( id, 3, 'Return', 260, 302, "000000000" )
	account.texts[ "exit" ] =
		ATM.TEXT_display( id, 4, 'Exit', 400, 302, "000000000" )

	--> Buttons
	local returnImageID = image( 'gfx/xNir/atm/menu/button_left.png', 240, 310,
		2, id )
	local exitImageID = image( 'gfx/xNir/atm/menu/button_right.png', 460, 310,
		2, id )

	--> Update
	account.images[ "return" ] = returnImageID
	account.images[ "exit" ] = exitImageID
end

--[[---------------------------------------------
	MENU_remove
-----------------------------------------------]]
function ATM.MENU_remove( id, all )
	local account = ATM.Accounts[ id ]

	--> Images Loop
	for key, imageID in pairs( account.images ) do
		if key ~= "box" and key ~= "bg" then
			freeimage( imageID )
			account.images[ key ] = nil
		else
			if all then
				freeimage( imageID )
				account.images[ key ] = nil
			end
		end
	end

	--> Texts Loop
	for key, txtID in pairs( account.texts ) do
		ATM.TEXT_clear( id, txtID )
		account.texts[ key ] = nil
	end
end

