--[[---------------------------------------------------------------------------
	
	Creator: x[N]ir - #4841
	This work is licensed under the Creative Commons 
	Attribution-NonCommercial-ShareAlike 4.0 International License. 
	License details: http://creativecommons.org/licenses/by-nc-sa/4.0/
	
-----------------------------------------------------------------------------]]

--[[---------------------------------------------
	ACCOUNT_load
-----------------------------------------------]]
function ATM.ACCOUNT_load( id )
	--> Vars
	local accountPath = "sys/lua/atm/data/accounts/" .. 
		player( id, "ip" ) .. ".acc"
	local account = ATM.Accounts[ id ]

	--> Exist
	if ATM.FILE_exist( accountPath ) then
		ATM.FILE_load( accountPath )

		local money = ATM.FILE_read()

		--> Money
		if not money or not money:match("^(%d+)$") then
			account.corrupted = true
			account.money = 0
			ATM.error( '<' .. accountPath .. '> is corrupted !' )
			return
		end

		account.money = tonumber( money )
		ATM.debug( 'Player <' .. id .. '> has been loaded !' )
	end
end

--[[---------------------------------------------
	ACCOUNT_save
-----------------------------------------------]]
function ATM.ACCOUNT_save( id )
	--> Vars
	local accountPath = "sys/lua/atm/data/accounts/" .. 
		player( id, "ip" ) .. ".acc"
	local account = ATM.Accounts[ id ]

	--> Corrupted
	if account.corrupted then
		ATM.debug( "Player <" .. id .. "> is corrupted and hasn't been saved !" )
		return
	end

	ATM.FILE_write( accountPath, { account.money } )
	ATM.debug( 'Player <' .. id .. '> has been saved !' )
end

--[[---------------------------------------------
	ACCOUNT_deposit
-----------------------------------------------]]
function ATM.ACCOUNT_deposit( id, amount )
	local money = player( id, "money" )

	--> Money
	if money < amount then
		return false
	end

	parse( 'setmoney ' .. id .. ' ' .. player( id, "money" ) - amount )

	--> Update
	ATM.Accounts[ id ].money = ATM.Accounts[ id ].money + amount
	ATM.ACCOUNT_save( id )
	ATM.MENU_deposit( id )
	return true
end

--[[---------------------------------------------
	ACCOUNT_withdraw
-----------------------------------------------]]
function ATM.ACCOUNT_withdraw( id, amount )
	local money = player( id, "money" )

	--> Money
	if money == 16000 then
		return false
	end

	local newMoney = money + amount
	local diff = 0

	--> New Money
	if newMoney > 16000 then
		diff = newMoney - 16000
	end

	local realAmount = amount - diff

	parse( 'setmoney ' .. id .. ' ' .. player( id, "money" ) + realAmount )

	--> Update
	ATM.Accounts[ id ].money = ATM.Accounts[ id ].money - realAmount
	ATM.ACCOUNT_save( id )
	ATM.MENU_withdraw( id )
	return true
end