--[[---------------------------------------------------------------------------
	
	Creator: x[N]ir - #4841
	This work is licensed under the Creative Commons 
	Attribution-NonCommercial-ShareAlike 4.0 International License. 
	License details: http://creativecommons.org/licenses/by-nc-sa/4.0/
	
-----------------------------------------------------------------------------]]

--[[---------------------------------------------
	Vars
-----------------------------------------------]]
ATM.Accounts = {}

ATM.Lines = {}
ATM.Line = 0

ATM.List = {}
ATM.Images = {}

ATM.INIT = 0
ATM.LOADING = 1
ATM.LOADED = 2

ATM.ERROR = -1
ATM.MAIN = 0
ATM.DEPOSIT = 1
ATM.WITHDRAW = 2
ATM.INFO = 3
ATM.EXIT = 4

--[[---------------------------------------------
	CORE_load
-----------------------------------------------]]
function ATM.CORE_load()
	--> ATM Loop
	for key, mapTab in pairs( ATM.Locations ) do
		if key == map( "name" ) then
			for _, pos in pairs( mapTab ) do
				ATM.List[ #ATM.List + 1 ] = {
					id = #ATM.List + 1,
					x = pos[ 1 ],
					y = pos[ 2 ],
					rot = pos[ 3 ] or 0,
					user = 0,
					imageID = nil,
					status = ATM.INIT,
					loadingPercent = 0,
					page = ATM.MAIN,
				}
			end
		end
	end

	ATM.Locations = nil
	ATM.debug( #ATM.List .. " ATM have been loaded ! " )
end

--[[---------------------------------------------
	CORE_placeATMs
-----------------------------------------------]]
function ATM.CORE_placeATMs()
	--> ATM Loop
	for _, atm in pairs( ATM.List ) do
		--> Image ID
		if not atm.imageID then
			atm.imageID = image( ATM.MODEL, atm.x, atm.y, 0 )
			imagepos( atm.imageID, atm.x, atm.y, atm.rot )
		end
	end
end

--[[---------------------------------------------
	CORE_removeATMs
-----------------------------------------------]]
function ATM.CORE_removeATMs()
	--> ATM Loop
	for _, atm in pairs( ATM.List ) do
		--> Image ID
		if atm.imageID then
			freeimage( atm.imageID )
			atm.imageID = nil
		end
	end
end

--[[---------------------------------------------
	CORE_start
-----------------------------------------------]]
function ATM.CORE_start( atm, id )
	atm.user = id
	ATM.MENU_init( id )

	parse( 'setweapon ' .. id .. ' 50' )
end

--[[---------------------------------------------
	CORE_getCurrentATM
-----------------------------------------------]]
function ATM.CORE_getCurrentATM( id )
	--> ATM Loop
	for _, atm in pairs( ATM.List ) do
		--> User
		if atm.user == id then
			return atm
		end
	end

	return nil
end

--[[---------------------------------------------
	CORE_process
-----------------------------------------------]]
function ATM.CORE_process( atm, mouseX, mouseY )
	freetimer( "parse", "lua ATM.die(" .. atm.user .. ")" )
	timer( ATM.AFK_DELAY * 1000, "parse", "lua ATM.die(" .. atm.user .. ")" )

	if atm.page == ATM.MAIN then
		ATM.CORE_main( atm, mouseX, mouseY )
	elseif atm.page == ATM.WITHDRAW then
		ATM.CORE_withdraw( atm, mouseX, mouseY )
	elseif atm.page == ATM.DEPOSIT then
		ATM.CORE_deposit( atm, mouseX, mouseY )
	elseif atm.page == ATM.INFO then
		ATM.CORE_info( atm, mouseX, mouseY )
	end
end

--[[---------------------------------------------
	CORE_main
-----------------------------------------------]]
function ATM.CORE_main( atm, mouseX, mouseY )
	--> Deposit
	if ATM.MATH_inRect( mouseX, mouseY, 226, 236, 32, 32 ) then
		ATM.MENU_deposit( atm.user )
		ATM.CORE_pressSFX( atm.user )
	end

	--> Withdraw
	if ATM.MATH_inRect( mouseX, mouseY, 445, 236, 32, 32 ) then
		ATM.MENU_withdraw( atm.user )
		ATM.CORE_pressSFX( atm.user )
	end

	--> Info
	if ATM.MATH_inRect( mouseX, mouseY, 226, 295, 32, 32 ) then
		ATM.MENU_info( atm.user )
		ATM.CORE_pressSFX( atm.user )
	end

	--> Exit
	if ATM.MATH_inRect( mouseX, mouseY, 445, 295, 32, 32 ) then
		ATM.CORE_exit( atm )
		ATM.CORE_pressSFX( atm.user )
	end
end

--[[---------------------------------------------
	CORE_deposit
-----------------------------------------------]]
function ATM.CORE_deposit( atm, mouseX, mouseY )
	local amount = 0

	--> b100
	if ATM.MATH_inRect( mouseX, mouseY, 226, 175, 32, 32 ) then
		amount = 100
		ATM.CORE_pressSFX( atm.user )
	end 

	--> b500
	if ATM.MATH_inRect( mouseX, mouseY, 445, 175, 32, 32 ) then
		amount = 500
		ATM.CORE_pressSFX( atm.user )
	end

	--> b1000
	if ATM.MATH_inRect( mouseX, mouseY, 226, 236, 32, 32 ) then
		amount = 1000
		ATM.CORE_pressSFX( atm.user )
	end

	--> b2000
	if ATM.MATH_inRect( mouseX, mouseY, 445, 236, 32, 32 ) then
		amount = 2000
		ATM.CORE_pressSFX( atm.user )
	end

	--> Return
	if ATM.MATH_inRect( mouseX, mouseY, 226, 295, 32, 32 ) then
		ATM.MENU_main( atm.user )
		ATM.CORE_pressSFX( atm.user )
		return
	end

	--> Amount
	if amount ~= 0 then
		if not ATM.ACCOUNT_deposit( atm.user, amount ) then
			ATM.MENU_error( atm.user, "Not enough money !" )
		end
	end
end

--[[---------------------------------------------
	CORE_withdraw
-----------------------------------------------]]
function ATM.CORE_withdraw( atm, mouseX, mouseY )
	local amount = 0

	--> b100
	if ATM.MATH_inRect( mouseX, mouseY, 226, 175, 32, 32 ) then
		amount = 100
		ATM.CORE_pressSFX( atm.user )
	end 

	--> b500
	if ATM.MATH_inRect( mouseX, mouseY, 445, 175, 32, 32 ) then
		amount = 500
		ATM.CORE_pressSFX( atm.user )
	end

	--> b1000
	if ATM.MATH_inRect( mouseX, mouseY, 226, 236, 32, 32 ) then
		amount = 1000
		ATM.CORE_pressSFX( atm.user )
	end

	--> b2000
	if ATM.MATH_inRect( mouseX, mouseY, 445, 236, 32, 32 ) then
		amount = 2000
		ATM.CORE_pressSFX( atm.user )
	end

	--> Return
	if ATM.MATH_inRect( mouseX, mouseY, 226, 295, 32, 32 ) then
		ATM.MENU_main( atm.user )
		ATM.CORE_pressSFX( atm.user )
		return
	end

	--> Amount
	if amount ~= 0 then
		if not ATM.ACCOUNT_withdraw( atm.user, amount ) then
			ATM.MENU_error( atm.user, "You can't take more money !" )
		end
	end
end

--[[---------------------------------------------
	CORE_info
-----------------------------------------------]]
function ATM.CORE_info( atm, mouseX, mouseY )
	--> Return
	if ATM.MATH_inRect( mouseX, mouseY, 226, 295, 32, 32 ) then
		ATM.MENU_main( atm.user )
		ATM.CORE_pressSFX( atm.user )
	end

	--> Exit
	if ATM.MATH_inRect( mouseX, mouseY, 445, 295, 32, 32 ) then
		ATM.CORE_exit( atm )
		ATM.CORE_pressSFX( atm.user )
	end
end

--[[---------------------------------------------
	CORE_exit
-----------------------------------------------]]
function ATM.CORE_exit( atm )
	--> Update
	atm.status = ATM.INIT
	atm.page = ATM.MAIN
	atm.loadingPercent = 0

	--> Exit
	ATM.MENU_exit( atm.user )

	--> Timer
	freetimer( "parse", "lua ATM.die(" .. atm.user .. ")" )
	timer( 1000, "parse", 'lua ATM.MENU_remove(' .. atm.user .. ',true)' )
	timer( 1000, "parse", 'lua ATM.List[' .. atm.id.. '].user=0' )
end

--[[---------------------------------------------
	CORE_reset
-----------------------------------------------]]
function ATM.CORE_reset( atm )
	atm.status = ATM.INIT
	atm.page = ATM.MAIN
	atm.loadingPercent = 0
	atm.user = 0

	freetimer( "parse", 'lua ATM.List[' .. atm.id.. '].user=0' )
end

--[[---------------------------------------------
	CORE_pressSFX
-----------------------------------------------]]
function ATM.CORE_pressSFX( id )
	parse( 'sv_soundpos "xNir/atm/press.wav" ' .. player( id, "x" ) .. 
		' ' .. player( id, "y" )  )
end